/*
    MapaJS. Generator atlasów oparty o mapy z zewnętrznych źródeł.
    Copyright (C) 2009  Marcin Szewczyk, Wodny, <mapa@wodny.org>

    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program.  If not, see <http://www.gnu.org/licenses/>.
*/



    var href_prefix = 'http://ars.geoportal.gov.pl/ARS/getTile.aspx?service=ORTOFOTO&cs=EPSG2180&fileIDX=';
    var empty_src = "img/empty.png";

    function genSrcByXY(x, y) {
      return href_prefix + "L3X" + x + "Y" + y + ".jpg";
    }

    function getMapDiv() {
      return document.getElementById("map");
    }

    function getMapOverlay() {
      return document.getElementById("map_overlay");
    }

    function addFotoMapSector(x, y) {
      var map = getMapDiv();
      var img = document.createElement("img");
      commonSectorAtts(img, x, y);
      map.appendChild(img);
    }

    function reduceIfEmpty(x, y) {
      if(isEmpty(x,y)) {
        reduceSector(x, y);
      }
    }

    function reduceSector(x, y) {
      var img = document.getElementById(genID(x, y));
      var over = document.getElementById(genOverID(x, y));
      if(onlyEmptyNeigh(x, y)) {
        getMapDiv().removeChild(img);
        getMapOverlay().removeChild(over);
      } else {
        img.setAttribute("src", empty_src);
      }
    }

    function commonOverlay(div, x, y) {
      div.setAttribute("style", genStyleByXY(x, y));
      div.setAttribute("id", genOverID(x, y));
      div.setAttribute("class", "overlay_sector");

      div.setAttribute("onClick", "handleOverlayClick(this)");
      div.setAttribute("onMouseOver", "handleOverlayOver(this)");
    }

    function addOverlay(x, y) {
      var overlay = getMapOverlay();
      var over = document.createElement("div");
      commonOverlay(over, x, y);
      overlay.appendChild(over);
    }

    function genOverID(x, y) {
      return "over:"+genID(x, y);
    }

    function commonSectorAtts(img, x, y) {
      img.setAttribute("style", genStyleByXY(x, y));
      img.setAttribute("id", genID(x, y));
      //img.setAttribute("onClick", "handleSectorClick(this)");
      //img.setAttribute("onMouseOver", "handleSectorOver(this)");
      img.setAttribute("name", genID(x, y));
      img.setAttribute("alt", genID(x, y));
    }

    function hasPrepared(x, y) {
      var img = document.getElementById(genID(x, y));
      if(!img) return false;

      return true;
    }

    function isFilled_ref(img) {
      return img.getAttribute("src") != empty_src;
    }

    function isFilled(x, y) {
      var img = document.getElementById(genID(x, y));
      return img.getAttribute("src") != empty_src;
    }

    function isEmpty(x, y) {
      var img = document.getElementById(genID(x, y));
      return !img || (img.getAttribute("src") == empty_src);
    }

    function almostEmptyNeigh(x, y) {
      var count = 0;
      count += isEmpty(x, y-1) ? 1 : 0;
      count += isEmpty(x-1, y) ? 1 : 0;
      count += isEmpty(x+1, y) ? 1 : 0;
      count += isEmpty(x, y+1) ? 1 : 0;
      return (count > 2) && (count < 4);
    }

    function onlyEmptyNeigh(x, y) {
      return isEmpty(x, y-1) && isEmpty(x-1,y) && isEmpty(x+1,y) && isEmpty(x,y+1);
    }

    function prepareSector(x, y) {
      var map = getMapDiv();
      if(hasPrepared(x, y)) return;

      var img = document.createElement("img");
      img.setAttribute("src", empty_src);
      commonSectorAtts(img, x, y);
      map.appendChild(img);

      addOverlay(x, y);
    }

    function addCross(x, y) {
      prepareSector(x, y-1);
      prepareSector(x-1, y);
      prepareSector(x+1, y);
      prepareSector(x, y+1);
    }

    function removeAllChildren(node) {
      while(node.hasChildNodes()) {
        node.removeChild(node.childNodes[0]);
      }
    }

    function genListBySectors() {
      var list = document.getElementById("sectors_list");

      list.value = "";

      var div = getMapDiv();
      if (div.hasChildNodes()) {
        var children = div.childNodes;
        for (var i = 0; i < children.length; i++) {
          if(isFilled_ref(children[i])) list.value += children[i].id+"\n";
        }
      }
    }

    function genSectorsByList() {
      var text = document.getElementById("sectors_list").value;

      var lines = text.split("\n");
      var xy;

      if(lines) {
        xy = lines[0].split(",", 2);
        if(xy.length != 2) {
          alertFormatErr("line 0, "+lines[0]);
          return;
        }
        center_id_x = parseInt(xy[0]);
        center_id_y = parseInt(xy[1]);
        start();
      } else {
        return;
      }

      for (var i = 1; i < lines.length; i++) {
        xy = lines[i].split(",", 2);
        if(xy.length != 2) {
          continue;
          //alertFormatErr("line "+i+", "+lines[i]);
          //return;
        }
        x = parseInt(xy[0]);
        y = parseInt(xy[1]);
        prepareSector(x, y);
        fillSector(x, y);
      }
    }

    function fotoShow() {
      var topo = getMapDiv();
      topo.style.display = 'block';
    }

    function fotoHide() {
      var topo = getMapDiv();
      topo.style.display = 'none';
    }
